@@ -3,21 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Portions Copyright (c) 1999 Apple Computer, Inc.  All Rights
- * Reserved.  This file contains Original Code and/or Modifications of
- * Original Code as defined in and that are subject to the Apple Public
- * Source License Version 1.1 (the "License").  You may not use this file
- * except in compliance with the License.  Please obtain a copy of the
- * License at http://www.apple.com/publicsource and read it before using
- * this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * 
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
  * 
  * The Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON- INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -124,7 +125,7 @@ char *dyld_image_suffix = NULL;
 char *dyld_insert_libraries = NULL;
 
 enum bool dyld_print_libraries = FALSE;
-enum bool dyld_trace = TRUE; /* to be turned off for Jaguar GM */
+enum bool dyld_trace = FALSE;
 enum bool dyld_mem_protect = FALSE;
 enum bool dyld_ebadexec_only = FALSE;
 enum bool dyld_dead_lock_hang = FALSE;
@@ -202,6 +203,7 @@ char **envp)
     unsigned int count;
     kern_return_t r;
     unsigned long entry_point;
+    mach_port_t my_mach_host_self;
 #ifndef __MACH30__
     struct section *s;
 #endif
@@ -218,10 +220,13 @@ char **envp)
 	 * Get the cputype and cpusubtype of the machine we're running on.
 	 */
 	count = HOST_BASIC_INFO_COUNT;
-	if((r = host_info(mach_host_self(), HOST_BASIC_INFO, (host_info_t)
+	my_mach_host_self = mach_host_self();
+	if((r = host_info(my_mach_host_self, HOST_BASIC_INFO, (host_info_t)
 			  (&host_basic_info), &count)) != KERN_SUCCESS){
+	    mach_port_deallocate(mach_task_self(), my_mach_host_self);
 	    mach_error(r, "can't get host basic info");
 	}
+	mach_port_deallocate(mach_task_self(), my_mach_host_self);
 #if defined(__GONZO_BUNSEN_BEAKER__) && defined(__ppc__)
 	if(host_basic_info.cpu_type == CPU_TYPE_POWERPC &&
 	   (host_basic_info.cpu_subtype == CPU_SUBTYPE_POWERPC_7400 ||
@@ -284,6 +289,8 @@ char **envp)
 	if((mh->flags & MH_FORCE_FLAT) != 0 ||
 	   dyld_force_flat_namespace == TRUE)
 	    force_flat_namespace = TRUE;
+	if((mh->flags & MH_NOFIXPREBINDING) == MH_NOFIXPREBINDING)
+	    dyld_no_fix_prebinding = TRUE;
 	executable_prebound = (mh->flags & MH_PREBOUND) == MH_PREBOUND;
 	load_executable_image(argv[0], mh, &entry_point);
 
@@ -408,9 +415,11 @@ char *envp[])
 		    if(getuid() != 0 &&
 		       (getuid() != geteuid() || getgid() != getegid()))
 			(*p)[sizeof("DYLD_FRAMEWORK_PATH=") - 1] = '\0';
-		    else if(*(*p + sizeof("DYLD_FRAMEWORK_PATH=") - 1) != '\0')
+		    else if(*(*p + sizeof("DYLD_FRAMEWORK_PATH=") - 1) != '\0'){
 			dyld_framework_path =
 				*p + sizeof("DYLD_FRAMEWORK_PATH=") - 1;
+			dyld_no_fix_prebinding = TRUE;
+		    }
 		}
 		else if(strncmp(*p, "DYLD_FALLBACK_FRAMEWORK_PATH=",
 		           sizeof("DYLD_FALLBACK_FRAMEWORK_PATH=") - 1) == 0){
@@ -418,9 +427,11 @@ char *envp[])
 		       (getuid() != geteuid() || getgid() != getegid()))
 			(*p)[sizeof("DYLD_FALLBACK_FRAMEWORK_PATH=")- 1] = '\0';
 		    else if(*(*p + sizeof(
-				"DYLD_FALLBACK_FRAMEWORK_PATH=") - 1) != '\0')
+				"DYLD_FALLBACK_FRAMEWORK_PATH=") - 1) != '\0'){
 			dyld_fallback_framework_path =
 			    *p + sizeof("DYLD_FALLBACK_FRAMEWORK_PATH=") - 1;
+			dyld_no_fix_prebinding = TRUE;
+		    }
 		}
 		else if(strncmp(*p, "DYLD_LIBRARY_PATH=",
 		                sizeof("DYLD_LIBRARY_PATH=") - 1) == 0){
@@ -436,9 +447,11 @@ char *envp[])
 		    if(getuid() != 0 &&
 		       (getuid() != geteuid() || getgid() != getegid()))
 			(*p)[sizeof("DYLD_LIBRARY_PATH=") - 1] = '\0';
-		    else if(*(*p + sizeof("DYLD_LIBRARY_PATH=") - 1) != '\0')
+		    else if(*(*p + sizeof("DYLD_LIBRARY_PATH=") - 1) != '\0'){
 			dyld_library_path =
 				*p + sizeof("DYLD_LIBRARY_PATH=") - 1;
+			dyld_no_fix_prebinding = TRUE;
+		    }
 		}
 		else if(strncmp(*p, "DYLD_FALLBACK_LIBRARY_PATH=",
 			    sizeof("DYLD_FALLBACK_LIBRARY_PATH=") - 1) == 0){
@@ -446,9 +459,11 @@ char *envp[])
 		       (getuid() != geteuid() || getgid() != getegid()))
 			(*p)[sizeof("DYLD_FALLBACK_LIBRARY_PATH=") - 1] = '\0';
 		    else if(*(*p + sizeof(
-				"DYLD_FALLBACK_LIBRARY_PATH=") - 1) != '\0')
+				"DYLD_FALLBACK_LIBRARY_PATH=") - 1) != '\0'){
 			dyld_fallback_library_path =
 				*p + sizeof("DYLD_FALLBACK_LIBRARY_PATH=") - 1;
+			dyld_no_fix_prebinding = TRUE;
+		    }
 		}
 		else if(strncmp(*p, "DYLD_IMAGE_SUFFIX=",
 		                sizeof("DYLD_IMAGE_SUFFIX=") - 1) == 0){
@@ -464,9 +479,11 @@ char *envp[])
 		    if(getuid() != 0 &&
 		       (getuid() != geteuid() || getgid() != getegid()))
 			(*p)[sizeof("DYLD_IMAGE_SUFFIX=") - 1] = '\0';
-		    else if(*(*p + sizeof("DYLD_IMAGE_SUFFIX=") - 1) != '\0')
+		    else if(*(*p + sizeof("DYLD_IMAGE_SUFFIX=") - 1) != '\0'){
 			dyld_image_suffix =
 				*p + sizeof("DYLD_IMAGE_SUFFIX=") - 1;
+			dyld_no_fix_prebinding = TRUE;
+		    }
 		}
 		else if(strncmp(*p, "DYLD_INSERT_LIBRARIES=",
 		                sizeof("DYLD_INSERT_LIBRARIES=") - 1) == 0){
@@ -481,9 +498,13 @@ char *envp[])
 		    if(getuid() != 0 &&
 		       (getuid() != geteuid() || getgid() != getegid()))
 			(*p)[sizeof("DYLD_INSERT_LIBRARIES=") - 1] = '\0';
-		    else if(*(*p + sizeof("DYLD_INSERT_LIBRARIES=")- 1) != '\0')
-			dyld_insert_libraries =
-				*p + sizeof("DYLD_INSERT_LIBRARIES=") - 1;
+		    else if(*(*p + sizeof("DYLD_INSERT_LIBRARIES=")- 1) !='\0'){
+			dyld_insert_libraries = malloc(strlen(
+				*p + sizeof("DYLD_INSERT_LIBRARIES=") - 1) + 1);
+			strcpy(dyld_insert_libraries,
+			       *p + sizeof("DYLD_INSERT_LIBRARIES=") - 1);
+			dyld_no_fix_prebinding = TRUE;
+		    }
 		}
 		else if(strncmp(*p, "DYLD_DEBUG_TRACE=",
 		                sizeof("DYLD_DEBUG_TRACE=") - 1) == 0){
@@ -533,6 +554,7 @@ char *envp[])
 		else if(strncmp(*p, "DYLD_NEW_LOCAL_SHARED_REGIONS=",
 			    sizeof("DYLD_NEW_LOCAL_SHARED_REGIONS=") - 1) == 0){
 		    dyld_new_local_shared_regions = TRUE;
+		    dyld_no_fix_prebinding = TRUE;
 		}
 		else if(strncmp(*p, "DYLD_NO_FIX_PREBINDING=",
 			    sizeof("DYLD_NO_FIX_PREBINDING=") - 1) == 0){
@@ -582,21 +604,7 @@ char *envp[])
 	 * just after the trailing 0 of the envp[] array.  If exec_path is left
 	 * as NULL other code will use argv[0] as a guess.
 	 */
-
-	/*
-	 * This feature was added to MacOS X PR2.  So in case we are running
-	 * with a kernel that does not set this we do a few checks on the
-	 * address of the pointer and the value of the pointer.  These checks
-	 * are temporary hacks and only work on PowerPC and i386 knowing the
-	 * address of the top of the stack (0xc0000000) and the stack grows
-	 * to lower addresses and that the bytes of the exec path should be
-	 * on the stack above the pointer.
-	 */
-	if((unsigned long)(p + 1) < 0xc0000000 &&
-	   (unsigned long)(p[1]) > (unsigned long)(p + 1) &&
-	   (unsigned long)(p[1]) < 0xc0000000){
-	    exec_path = p[1];
-	}
+	exec_path = p[1];
 	if(dyld_executable_path_debug == TRUE)
 	    printf("exec_path = %s\n", exec_path == NULL ? "NULL" : exec_path);
 #endif
@@ -626,27 +634,6 @@ void)
 	return(&pp);
 }
 
-/*
- * These are dummy versions to avoid having to link with libmathCommon.a in
- * Mac OS X 10.2 (Jaguar) and beond.  They are only used with printf and dyld
- * does not print floating point.
- */
-double
-__inf(void)
-{
-	return(0.0);
-}
-long
-__isnand(double x)
-{
-	return(0);
-}
-long
-__isinfd(double x)
-{
-	return(0);
-}
-
 #ifdef DYLD_PROFILING
 /*
  * profiling_exit is used as the symbol "__exit" in the routines
