@@ -3,21 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Portions Copyright (c) 1999 Apple Computer, Inc.  All Rights
- * Reserved.  This file contains Original Code and/or Modifications of
- * Original Code as defined in and that are subject to the Apple Public
- * Source License Version 1.1 (the "License").  You may not use this file
- * except in compliance with the License.  Please obtain a copy of the
- * License at http://www.apple.com/publicsource and read it before using
- * this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * 
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
  * 
  * The Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON- INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -206,6 +207,7 @@ void)
 
 	/* TODO: figure out what to do for debugging */
 
+	halt();
 	exit(DYLD_EXIT_FAILURE_BASE + DYLD_UNDEFINED);
 
 	/* just here to keep the compiler happy */
@@ -295,6 +297,7 @@ char *prev_module_name)
 
 	/* TODO: figure out what to do for debugging */
 
+	halt();
 	exit(DYLD_EXIT_FAILURE_BASE + DYLD_MULTIPLY_DEFINED);
 }
 
@@ -312,6 +315,7 @@ void)
 	error("Call to undefined routine after a NSUnLinkModule with the "
 	      "NSUNLINKMODULE_OPTION_RESET_LAZY_REFERENCES option");
 	link_edit_error(DYLD_OTHER_ERROR, DYLD_LAZY_BIND, NULL);
+	halt();
 	exit(DYLD_EXIT_FAILURE_BASE + DYLD_OTHER_ERROR);
 }
 
@@ -333,6 +337,7 @@ void)
 	     for(;;)
 		;
 	}
+	halt();
 	exit(DYLD_EXIT_FAILURE_BASE + DYLD_DEAD_LOCK);
 }
 
@@ -431,6 +436,7 @@ char *file_name)
 	}
 
 	/* TODO: figure out what to do for debugging */
+	halt();
 	exit(DYLD_EXIT_FAILURE_BASE + error_class);
 }
 
@@ -442,6 +448,7 @@ abort(
 void)
 {
 	kill(getpid(), SIGABRT);
+	halt();
 	exit(DYLD_EXIT_FAILURE_BASE + DYLD_UNIX_RESOURCE);
 }
 
