@@ -3,21 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Portions Copyright (c) 1999 Apple Computer, Inc.  All Rights
- * Reserved.  This file contains Original Code and/or Modifications of
- * Original Code as defined in and that are subject to the Apple Public
- * Source License Version 1.1 (the "License").  You may not use this file
- * except in compliance with the License.  Please obtain a copy of the
- * License at http://www.apple.com/publicsource and read it before using
- * this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * 
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
  * 
  * The Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON- INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -57,6 +58,7 @@
 #endif /* defined(RLD) && !defined(SA_RLD) &&
 	  !(defined(KLD) && defined(__STATIC__)) */
 #include "stuff/arch.h"
+#include "stuff/macosx_deployment_target.h"
 
 #include "ld.h"
 #include "specs.h"
@@ -297,12 +299,12 @@ layout(void)
 	 */
 	layout_segments();
 
+#ifndef RLD
 	/*
 	 * For symbol from dylibs reset the prebound symbols if not prebinding.
 	 */
 	reset_prebound_undefines();
 
-#ifndef RLD
 	if(load_map)
 	    print_load_map();
 #endif !defined(RLD)
@@ -1173,6 +1175,8 @@ layout_segments(void)
 		output_mach_header.flags |= MH_FORCE_FLAT;
 	    if(nomultidefs)
 		output_mach_header.flags |= MH_NOMULTIDEFS;
+	    if(no_fix_prebinding)
+		output_mach_header.flags |= MH_NOFIXPREBINDING;
 	}
 
 	/*
@@ -1614,6 +1618,8 @@ layout_segments(void)
 	    }
 	    p = &(msg->next);
 	}
+	if(i > MAX_SECT)
+	    fatal("too many sections used, maximum is: %d", MAX_SECT);
 
 #ifndef RLD
 	/*
