@@ -3,21 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Portions Copyright (c) 1999 Apple Computer, Inc.  All Rights
- * Reserved.  This file contains Original Code and/or Modifications of
- * Original Code as defined in and that are subject to the Apple Public
- * Source License Version 1.1 (the "License").  You may not use this file
- * except in compliance with the License.  Please obtain a copy of the
- * License at http://www.apple.com/publicsource and read it before using
- * this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * 
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
  * 
  * The Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON- INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -336,13 +337,6 @@ struct section_map *section_map)
 				  nlists[symbolnum].n_un.n_strx);
 			}
 			merged_symbol = *hash_pointer;
-			if(((merged_symbol->nlist.n_type & N_PEXT) == N_PEXT &&
-			    keep_private_externs == FALSE) ||
-			   dynamic == FALSE ||
-			   (output_for_dyld && has_dynamic_linker_command))
-			    force_extern_reloc = FALSE;
-			else
-			    force_extern_reloc = TRUE;
 		    }
 		    else{
 			if(nlists[symbolnum].n_type != (N_EXT | N_UNDF)){
@@ -358,6 +352,17 @@ struct section_map *section_map)
 			    " in above file not in undefined map", symbolnum);
 		    }
 		}
+		if((merged_symbol->nlist.n_type & N_TYPE) == N_SECT &&
+		   (get_output_section(merged_symbol->nlist.n_sect)->
+		    flags & SECTION_TYPE) == S_COALESCED){
+		    if(((merged_symbol->nlist.n_type & N_PEXT) == N_PEXT &&
+			keep_private_externs == FALSE) ||
+		       dynamic == FALSE ||
+		       (output_for_dyld && has_dynamic_linker_command))
+			force_extern_reloc = FALSE;
+		    else
+			force_extern_reloc = TRUE;
+		}
 		/*
 		 * If this is an indirect symbol resolve indirection (all chains
 		 * of indirect symbols have been resolved so that they point at
