@@ -3,21 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Portions Copyright (c) 1999 Apple Computer, Inc.  All Rights
- * Reserved.  This file contains Original Code and/or Modifications of
- * Original Code as defined in and that are subject to the Apple Public
- * Source License Version 1.1 (the "License").  You may not use this file
- * except in compliance with the License.  Please obtain a copy of the
- * License at http://www.apple.com/publicsource and read it before using
- * this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * 
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
  * 
  * The Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON- INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -926,6 +927,7 @@ struct _dyld_debug_task_state *state)
     kern_return_t k;
     struct host_sched_info info;
     enum bool core_task;
+    mach_port_t my_mach_host_self;
 
 	state->debug_thread = MACH_PORT_NULL;
 	state->debug_port = MACH_PORT_NULL;
@@ -1114,8 +1116,10 @@ struct _dyld_debug_task_state *state)
 	     * section of that task.
 	     */
 	    count1 = HOST_SCHED_INFO_COUNT;
-	    k = host_info(mach_host_self(), HOST_SCHED_INFO,
+	    my_mach_host_self = mach_host_self();
+	    k = host_info(my_mach_host_self, HOST_SCHED_INFO,
 			  (host_info_t)(&info), &count1);
+	    mach_port_deallocate(mach_task_self(), my_mach_host_self);
 	    if(k != KERN_SUCCESS){
 		SET_MACH_DYLD_DEBUG_ERROR(k, 56);
 		return(DYLD_FAILURE);
