@@ -3,21 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Portions Copyright (c) 1999 Apple Computer, Inc.  All Rights
- * Reserved.  This file contains Original Code and/or Modifications of
- * Original Code as defined in and that are subject to the Apple Public
- * Source License Version 1.1 (the "License").  You may not use this file
- * except in compliance with the License.  Please obtain a copy of the
- * License at http://www.apple.com/publicsource and read it before using
- * this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * 
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
  * 
  * The Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON- INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -116,6 +117,7 @@ unsigned long *throttle)
     unsigned long mh_flags;
     struct load_command *lc;
     struct dylib_command *dl;
+    mach_port_t my_mach_host_self;
 
     /*
      * The time the table of contents' are set to and the time to base the
@@ -419,7 +421,9 @@ unsigned long *throttle)
 		    for(j = 0; j < archs[i].object->mh->ncmds; j++){
 			if(lc->cmd == LC_ID_DYLIB){
 			    dl = (struct dylib_command *)lc;
-			    dl->dylib.timestamp = timestamp;
+			    if(archs[i].dont_update_LC_ID_DYLIB_timestamp ==
+			       FALSE)
+				dl->dylib.timestamp = timestamp;
 			    break;
 			}
 			lc = (struct load_command *)((char *)lc + lc->cmdsize);
@@ -493,10 +497,13 @@ unsigned long *throttle)
 	    bytes_written = 0;
 	    bytes_per_second = 0;
 	    count = HOST_SCHED_INFO_COUNT;
-	    if((r = host_info(mach_host_self(), HOST_SCHED_INFO, (host_info_t)
+	    my_mach_host_self = mach_host_self();
+	    if((r = host_info(my_mach_host_self, HOST_SCHED_INFO, (host_info_t)
 			      (&info), &count)) != KERN_SUCCESS){
+		mach_port_deallocate(mach_task_self(), my_mach_host_self);
 		my_mach_error(r, "can't get host sched info");
 	    }
+	    mach_port_deallocate(mach_task_self(), my_mach_host_self);
 	    if(gettimeofday(&start, &tz) == -1)
 		goto no_throttle;
 #undef THROTTLE_DEBUG
