@@ -3,21 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Portions Copyright (c) 1999 Apple Computer, Inc.  All Rights
- * Reserved.  This file contains Original Code and/or Modifications of
- * Original Code as defined in and that are subject to the Apple Public
- * Source License Version 1.1 (the "License").  You may not use this file
- * except in compliance with the License.  Please obtain a copy of the
- * License at http://www.apple.com/publicsource and read it before using
- * this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * 
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
  * 
  * The Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON- INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -647,7 +648,9 @@ char **envp)
 			strcmp(argv[i], "-flat_namespace") == 0 ||
 			strcmp(argv[i], "-nomultidefs") == 0 ||
 			strcmp(argv[i], "-headerpad_max_install_names") == 0 ||
-			strcmp(argv[i], "-prebind_all_twolevel_modules") == 0){
+			strcmp(argv[i], "-prebind_all_twolevel_modules") == 0 ||
+			strcmp(argv[i], "-ObjC") == 0 ||
+			strcmp(argv[i], "-M") == 0){
 		    if(cmd_flags.ranlib == TRUE){
 			error("unknown option: %s", argv[i]);
 			usage();
@@ -1391,9 +1394,26 @@ struct ofile *ofile)
 	     * library to be created fat unless there are object going into
 	     * the library that are fat.
 	     */
-	    if(cmd_flags.dynamic == TRUE &&
-	       ofile->mh->filetype == MH_DYLIB)
+	    if(ofile->mh->filetype == MH_DYLIB){
+		/*
+		 * If we are building a static library we should not put a
+		 * dynamic library Mach-O file into the static library.  This
+		 * can happen if a libx.a file is really a dynamic library and
+		 * someone is using -lx when creating a static library.
+		 */
+		if(cmd_flags.dynamic != TRUE){
+		    if(ofile->member_ar_hdr != NULL){
+			warning("file: %s(%.*s) is a dynamic library, not "
+				"added to the static library", 
+			        ofile->file_name, (int)ofile->member_name_size,
+			        ofile->member_name);
+		    }
+		    else
+			warning("file: %s is a dynamic library, not added to "
+				"the static library", ofile->file_name);
+		}
 		return;
+	    }
 	    /*
 	     * If -arch_only is specified then only add this file if it matches
 	     * the architecture specified.
