@@ -3,21 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Portions Copyright (c) 1999 Apple Computer, Inc.  All Rights
- * Reserved.  This file contains Original Code and/or Modifications of
- * Original Code as defined in and that are subject to the Apple Public
- * Source License Version 1.1 (the "License").  You may not use this file
- * except in compliance with the License.  Please obtain a copy of the
- * License at http://www.apple.com/publicsource and read it before using
- * this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * 
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
  * 
  * The Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON- INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -894,10 +895,11 @@ char *arch_name)
 		break;
 	    case N_SECT:
 		if(symbols[i].n_sect >= 1 &&
-		   symbols[i].n_sect <= process_flags->nsects)
+		   symbols[i].n_sect <= process_flags->nsects){
 		    printf(" (%.16s,%.16s) ",
 		       process_flags->sections[symbols[i].n_sect-1]->segname,
 		       process_flags->sections[symbols[i].n_sect-1]->sectname);
+		}
 		else
 		    printf(" (?,?) ");
 		break;
@@ -909,10 +911,15 @@ char *arch_name)
 	    if(symbols[i].n_type & N_EXT){
 		if(symbols[i].n_desc & REFERENCED_DYNAMICALLY)
 		    printf("[referenced dynamically] ");
-		if(symbols[i].n_type & N_PEXT)
-		    printf("private external ");
+		if(symbols[i].n_type & N_PEXT){
+		    if((symbols[i].n_desc & N_WEAK_DEF) == N_WEAK_DEF)
+			printf("weak private external ");
+		    else
+			printf("private external ");
+		}
 		else{
-		    if(symbols[i].n_desc & N_WEAK_REF)
+		    if((symbols[i].n_desc & N_WEAK_REF) == N_WEAK_REF ||
+		       (symbols[i].n_desc & N_WEAK_DEF) == N_WEAK_DEF)
 			printf("weak external ");
 		    else
 			printf("external ");
