@@ -3,21 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Portions Copyright (c) 1999 Apple Computer, Inc.  All Rights
- * Reserved.  This file contains Original Code and/or Modifications of
- * Original Code as defined in and that are subject to the Apple Public
- * Source License Version 1.1 (the "License").  You may not use this file
- * except in compliance with the License.  Please obtain a copy of the
- * License at http://www.apple.com/publicsource and read it before using
- * this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * 
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
  * 
  * The Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON- INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -215,13 +216,14 @@ char **envp)
     unsigned long i, j, nfiles;
     struct arch_flag *arch_flags;
     unsigned long narch_flags;
-    enum bool all_archs;
+    enum bool all_archs, use_member_syntax;
     char **files;
 
 	progname = argv[0];
 	arch_flags = NULL;
 	narch_flags = 0;
 	all_archs = FALSE;
+	use_member_syntax = TRUE;
 
 	if(argc <= 1)
 	    usage();
@@ -380,6 +382,9 @@ char **envp)
 		case 'Z':
 		    Zflag = TRUE;
 		    break;
+		case 'm':
+		    use_member_syntax = FALSE;
+		    break;
 		default:
 		    error("unknown char `%c' in flag %s\n", argv[i][j],argv[i]);
 		    usage();
@@ -419,7 +424,7 @@ char **envp)
 
 	for(i = 0; i < nfiles; i++){
 	    ofile_process(files[i], arch_flags, narch_flags, all_archs, TRUE,
-			  TRUE, TRUE, processor, NULL);
+			  TRUE, use_member_syntax, processor, NULL);
 	}
 
 	if(errors)
@@ -437,7 +442,7 @@ usage(
 void)
 {
 	fprintf(stderr,
-		"Usage: %s [-fahlLtdorSvVc] <object file> ...\n",
+		"Usage: %s [-fahlLDtdorSTMRIHvVcXm] <object file> ...\n",
 		progname);
 
 	fprintf(stderr, "\t-f print the fat headers\n");
@@ -467,6 +472,7 @@ void)
 	fprintf(stderr, "\t-V print disassembled operands symbolicly\n");
 	fprintf(stderr, "\t-c print argument strings of a core file\n");
 	fprintf(stderr, "\t-X print no leading addresses or headers\n");
+	fprintf(stderr, "\t-m don't use archive(member) syntax\n");
 	exit(EXIT_FAILURE);
 }
 
